"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const server_1 = __importDefault(require("react-dom/server"));
const react_router_dom_1 = require("react-router-dom");
const context_1 = require("../../shared/context");
const main_layout_1 = require("../layouts/main-layout");
const routes_1 = require("../../shared/routes");
const sdk_1 = require("../components/sdk");
const constants_1 = require("../../shared/constants");
function getPageMeta(page) {
    return {
        name: page.name,
        rating: page.rating,
        tags: page.tags,
        wikiName: page.wikiName,
        title: page.title,
    };
}
exports.default = (req, res) => __awaiter(void 0, void 0, void 0, function* () {
    const context = {};
    let dataPreload = Promise.resolve({});
    routes_1.routes.some((route) => {
        const match = react_router_dom_1.matchPath(req.path, route);
        if (match && route.preloadDataMethod) {
            const params = match.params;
            switch (route.preloadDataMethod) {
                case 'wikidot-page':
                    dataPreload = sdk_1.sdk.getWikidotPage(params.pageName);
                    break;
            }
        }
        return match;
    });
    const preloadedData = (yield dataPreload) || 'page-not-found';
    const appContext = {
        user: req.userInfo,
        preloadedData: preloadedData,
    };
    const clientContext = {
        user: req.userInfo,
        preloadedData: preloadedData && Object.assign(Object.assign({}, getPageMeta(preloadedData)), { content: constants_1.SSR_HYDRATE_KEYWORD }),
    };
    const renderedPage = server_1.default.renderToString((react_1.default.createElement(context_1.AppContext.Provider, { value: appContext },
        react_1.default.createElement(react_router_dom_1.StaticRouter, { location: req.url, context: context },
            react_1.default.createElement(routes_1.App, null)))));
    if (context.url) {
        res.redirect(301, context.url);
        return;
    }
    else if (context.statusCode === 404) {
        res.status(404).send('Not found');
        return;
    }
    res.status(200).send(main_layout_1.generateLayout({
        title: (preloadedData === null || preloadedData === void 0 ? void 0 : preloadedData.title) || 'SCP Foundation',
        content: renderedPage,
        data: clientContext,
        devMode: req.devMode,
    }));
});
//# sourceMappingURL=ui.js.map