"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clearNulls = exports.logImportant = exports.reportError = exports.log = exports.logger = exports.sentry = void 0;
const pino = require("pino");
const Sentry = require("raven");
const { SENTRY_DSN } = process.env;
Sentry.config(SENTRY_DSN).install();
exports.sentry = Sentry;
const prettyPrint = process.env.DEV_MODE ?
    { ignore: 'hostname,pid', translateTime: 'HH:mm' } :
    false;
exports.logger = pino({ prettyPrint });
function log(message, args) {
    if (args) {
        exports.logger.info(args, message);
    }
    else {
        exports.logger.info(message);
    }
}
exports.log = log;
function reportError(error, args) {
    const callArgs = [error];
    if (args) {
        if (args.message) {
            callArgs.push(args.message);
        }
        if (args.extra) {
            callArgs.push(args.extra);
        }
    }
    exports.logger.error(...callArgs); // eslint-disable-line @typescript-eslint/no-explicit-any
    exports.sentry.captureException(error, args);
}
exports.reportError = reportError;
function logImportant(message) {
    log(`[Important] ${message}`);
}
exports.logImportant = logImportant;
var queues_1 = require("../components/queues");
Object.defineProperty(exports, "enqueue", { enumerable: true, get: function () { return queues_1.enqueue; } });
Object.defineProperty(exports, "batchedEnqueue", { enumerable: true, get: function () { return queues_1.batchedEnqueue; } });
function clearNulls(input) {
    return Object.keys(input).reduce((acc, current) => {
        if (input[current] !== null) {
            acc[current] = input[current];
        }
        return acc;
    }, {});
}
exports.clearNulls = clearNulls;
//# sourceMappingURL=utils.js.map