"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const queues_1 = require("../components/queues");
const tasks_executer_1 = __importDefault(require("../components/tasks-executer"));
function taskRunner(job) {
    return tasks_executer_1.default(job.data.task, job.data.args)
        .catch((error) => {
        utils_1.reportError(error, {
            message: 'Error during task processing',
            extra: {
                task: job.data.task,
                args: job.data.args,
            },
        });
        throw error;
    });
}
function runWorker() {
    return __awaiter(this, void 0, void 0, function* () {
        utils_1.log('Initiating worker process');
        yield queues_1.bossReady;
        queues_1.boss.on('error', (error) => {
            utils_1.reportError(error, {
                message: 'Error during task processing',
            });
        });
        yield queues_1.boss.subscribe('common', {
            teamSize: 4,
            teamConcurrency: 4,
        }, taskRunner);
        yield queues_1.boss.subscribe('import', {
            teamSize: 4,
            teamConcurrency: 4,
        }, taskRunner);
        utils_1.log('Worker initiated');
    });
}
exports.default = runWorker;
//# sourceMappingURL=worker.js.map