"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.tetherAccount = exports.TetherResult = void 0;
const wikidot_kit_1 = require("../components/wikidot-kit");
const models_1 = require("../models");
const MIGRATION_WIKI_NAME = 'scp-migration';
const PAGE_NOT_FOUND_CODE = 406;
var TetherResult;
(function (TetherResult) {
    TetherResult["Ok"] = "Ok";
    TetherResult["PageNotFound"] = "PageNotFound";
    TetherResult["AlreadyTethered"] = "AlreadyTethered";
    TetherResult["WikidotUserAlreadyTethered"] = "WikidotUserAlreadyTethered";
})(TetherResult = exports.TetherResult || (exports.TetherResult = {}));
function tetherAccount(userId) {
    return __awaiter(this, void 0, void 0, function* () {
        const pageName = `scp-id-${userId}`;
        try {
            const tetherPage = yield wikidot_kit_1.wk.fetchPage(MIGRATION_WIKI_NAME, pageName);
            const author = tetherPage.created_by;
            const user = yield models_1.User.query().select('*').where({ id: userId }).first();
            if (user.wikidotUid) {
                return { result: TetherResult.AlreadyTethered };
            }
            const existingUser = yield models_1.User.query().select('*').where({ username: author }).first();
            if (existingUser && existingUser.wikidotUid) {
                return { result: TetherResult.WikidotUserAlreadyTethered };
            }
            yield models_1.User
                .query()
                .update({
                username: author,
                wikidotUid: -Math.ceil(Math.random() * 10e5),
            })
                .where({ id: userId });
            return { result: TetherResult.Ok };
        }
        catch (error) {
            if (error.code === PAGE_NOT_FOUND_CODE) {
                return { result: TetherResult.PageNotFound };
            }
            throw error;
        }
    });
}
exports.tetherAccount = tetherAccount;
//# sourceMappingURL=wikidot-tethering.service.js.map